@@ -1,7 +1,8 @@
 # test.prolog.R
 
-printf <- function(fmt, ...) cat(sprint(fmt, ...), sep="")
+printf <- function(fmt, ...) cat(sprintf(fmt, ...), sep="")
 cat0 <- function(...) cat(..., sep="")
+strip.space <- function(s) gsub("[ \t\n]", "", s)
 # test that we got an error as expected from a try() call
 expect.err <- function(object, expected.msg="")
 {
@@ -16,7 +17,12 @@ expect.err <- function(object, expected.msg="")
     } else
         stop("Did not get expected error: ", expected.msg)
 }
+empty.plot <- function()
+{
+    plot(0, 0, col=0, bty="n", xaxt="n", yaxt="n", xlab="", ylab="", main="")
+}
 options(warn=1) # print warnings as they occur
+# we include extra postscript fonts so can test prp arguments like fam.main
 if(!interactive())
     postscript(paper="letter", fonts=c("Helvetica", "NewCenturySchoolbook"))
 old.par <- par(no.readonly=TRUE)
