@@ -3,9 +3,6 @@
 
 source("test.prolog.R")
 
-dummy.plot <- function() {
-    plot(0, 0, col=0, bty="n", xlab="", ylab="", xaxt="n", yaxt="n")
-}
 print(sessionInfo())
 print(citation("rpart.plot"))
 
@@ -529,9 +526,9 @@ prp(a4, type=1, yesno=T, faclen=-1, under=F, extra=107, cex.main=.9, main="extra
 prp(a4, type=1, yesno=T, faclen=-1, under=F, extra=108, cex.main=.9, main="extra=108\nunder=F")
 prp(a4, type=1, yesno=T, faclen=-1, under=F, extra=109, cex.main=.9, main="extra=109\n under=F")
 
-dummy.plot()
-dummy.plot()
-dummy.plot()
+empty.plot()
+empty.plot()
+empty.plot()
 prp(a4, type=1, yesno=T, faclen=-1, under=T, extra=0, cex.main=.9, main="extra=0\nunder=T")
 prp(a4, type=1, yesno=T, faclen=-1, under=T, extra=1, cex.main=.9, main="extra=1\nunder=T")
 prp(a4, type=1, yesno=T, faclen=-1, under=T, extra=4, cex.main=.9, main="extra=4\nunder=T")
@@ -555,14 +552,14 @@ par(mfrow=c(9,4), mar = c(4, 3, 2, 1), mgp = c(1.5, .5, 0))
 
 a4 <- rpart(survived~., data=ptitanic, cp=.03)
 plot(a4, unif=T, branch=.3); text(a4, use.n=1, cex=1, xpd=NA, pretty=0); title("Page 16", cex.main=.9)
-dummy.plot()
-dummy.plot()
-dummy.plot()
-dummy.plot()
-dummy.plot()
-dummy.plot()
-dummy.plot()
-dummy.plot()
+empty.plot()
+empty.plot()
+empty.plot()
+empty.plot()
+empty.plot()
+empty.plot()
+empty.plot()
+empty.plot()
 prp(a4, type=1, yesno=T, faclen=-1, under=F, extra=100, under.percent=0, cex.main=.9, main="extra=100\nunder=F under.percent=0")
 prp(a4, type=1, yesno=T, faclen=-1, under=F, extra=101, under.percent=0, cex.main=.9, main="extra=101\nunder=F under.percent=0")
 prp(a4, type=1, yesno=T, faclen=-1, under=F, extra=104, under.percent=0, cex.main=.9, main="extra=104\nunder=F under.percent=0")
@@ -572,18 +569,18 @@ prp(a4, type=1, yesno=T, faclen=-1, under=F, extra=107, under.percent=0, cex.mai
 prp(a4, type=1, yesno=T, faclen=-1, under=F, extra=108, under.percent=0, cex.main=.9, main="extra=108\nunder=F under.percent=0")
 prp(a4, type=1, yesno=T, faclen=-1, under=F, extra=109, under.percent=0, cex.main=.9, main="extra=109\n under=F under.percent=0")
 
-dummy.plot()
-dummy.plot()
-dummy.plot()
+empty.plot()
+empty.plot()
+empty.plot()
 
-dummy.plot()
-dummy.plot()
-dummy.plot()
-dummy.plot()
-dummy.plot()
-dummy.plot()
-dummy.plot()
-dummy.plot()
+empty.plot()
+empty.plot()
+empty.plot()
+empty.plot()
+empty.plot()
+empty.plot()
+empty.plot()
+empty.plot()
 prp(a4, type=1, yesno=T, faclen=-1, under=T, extra=100, under.percent=0, cex.main=.9, main="extra=100\nunder=T under.percent=0")
 prp(a4, type=1, yesno=T, faclen=-1, under=T, extra=101, under.percent=0, cex.main=.9, main="extra=101\nunder=T under.percent=0")
 prp(a4, type=1, yesno=T, faclen=-1, under=T, extra=104, under.percent=0, cex.main=.9, main="extra=104\nunder=T under.percent=0")
@@ -599,14 +596,14 @@ par(mfrow=c(9,4), mar = c(4, 3, 2, 1), mgp = c(1.5, .5, 0))
 
 a4 <- rpart(survived~., data=ptitanic, cp=.03)
 plot(a4, unif=T, branch=.3); text(a4, use.n=1, cex=1, xpd=NA, pretty=0); title("Page 17", cex.main=.9)
-dummy.plot()
-dummy.plot()
-dummy.plot()
-dummy.plot()
-dummy.plot()
-dummy.plot()
-dummy.plot()
-dummy.plot()
+empty.plot()
+empty.plot()
+empty.plot()
+empty.plot()
+empty.plot()
+empty.plot()
+empty.plot()
+empty.plot()
 prp(a4, type=1, yesno=T, faclen=-1, under=F, extra=100, under.percent=1, cex.main=.9, main="extra=100\nunder=F under.percent=1")
 prp(a4, type=1, yesno=T, faclen=-1, under=F, extra=101, under.percent=1, cex.main=.9, main="extra=101\nunder=F under.percent=1")
 prp(a4, type=1, yesno=T, faclen=-1, under=F, extra=104, under.percent=1, cex.main=.9, main="extra=104\nunder=F under.percent=1")
@@ -616,18 +613,18 @@ prp(a4, type=1, yesno=T, faclen=-1, under=F, extra=107, under.percent=1, cex.mai
 prp(a4, type=1, yesno=T, faclen=-1, under=F, extra=108, under.percent=1, cex.main=.9, main="extra=108\nunder=F under.percent=1")
 prp(a4, type=1, yesno=T, faclen=-1, under=F, extra=109, under.percent=1, cex.main=.9, main="extra=109\n under=F under.percent=1")
 
-dummy.plot()
-dummy.plot()
-dummy.plot()
+empty.plot()
+empty.plot()
+empty.plot()
 
-dummy.plot()
-dummy.plot()
-dummy.plot()
-dummy.plot()
-dummy.plot()
-dummy.plot()
-dummy.plot()
-dummy.plot()
+empty.plot()
+empty.plot()
+empty.plot()
+empty.plot()
+empty.plot()
+empty.plot()
+empty.plot()
+empty.plot()
 prp(a4, type=1, yesno=T, faclen=-1, under=T, extra=100, under.percent=1, cex.main=.9, main="extra=100\nunder=T under.percent=1")
 prp(a4, type=1, yesno=T, faclen=-1, under=T, extra=101, under.percent=1, cex.main=.9, main="extra=101\nunder=T under.percent=1")
 prp(a4, type=1, yesno=T, faclen=-1, under=T, extra=104, under.percent=1, cex.main=.9, main="extra=104\nunder=T under.percent=1")
